TotpOptions

Struct TotpOptions 

pub struct TotpOptions<'a> {
    pub key: &'a [u8],
    pub digits: u32,
    pub step: u64,
    pub epoch: u64,
    pub timestamp: u64,
}
Options for generating TOTP codes.

Fields

key: &'a [u8]

The secret, shared key to use to generate the code.

digits: u32

The number of digits that should be in the code.

Defaults to 6.

step: u64

The number of seconds in a generation window.

Defaults to 30.

epoch: u64

The seconds from the Unix epoch to use as T0.

Defaults to 0.

timestamp: u64

The timestamp to generate the TOTP code at.

Defaults to the current system time if std or libc are enabled.